=========
Changelog
=========

Version v0.0.X
==============

- Switch to PyScaffold v2.5.11

Version v0.0.1
==============

- Add class SmartPath, SmartTree and SmartFilename
- Add class SgrtFilename and function sgrt_path
- Add unit tests
